@@ -3473,7 +3473,7 @@ e_book_backend_ldap_remove (EBookBackend *backend, EDataBook *book, guint32 opid
 static char*
 e_book_backend_ldap_get_static_capabilities (EBookBackend *backend)
 {
-	return g_strdup("net");
+	return g_strdup("net,anon-access");
 }
 
 static gboolean
@@ -3551,7 +3551,7 @@ e_book_backend_ldap_dispose (GObject *object)
 
 		g_free (bl->priv->ldap_host);
 		g_free (bl->priv->ldap_rootdn);
-		
+		g_free (bl->priv->schema_dn);
 		g_free (bl->priv);
 		bl->priv = NULL;
 	}
